powered by
This function using normal return model to simulate price under price limit condition.
Price limit condition require that the return on price is limited.
Related report: Value at Risk.
jMCPriLim(s0, L, U, mu, sigma,m)
s0 <- 100 mu <- 0.02 sigma <- 0.1 m <- 1000 L <- -0.07 U <- 0.07 jMCPriLim (s0, L, U, mu, sigma, m)
Run the code above in your browser using DataLab